==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/GroupsFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Groups}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class GroupsFieldAttributes extends AbstractBeanAttributesDefinition{

    /** defaultGroup (Database column: DEFAULT_GROUP) */
    static public AttributeDefinition defaultGroup =
        new AttributeDefinition("defaultGroup")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("DEFAULT_GROUP")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(boolean.class);

    /** description (Database column: DESCRIPTION) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** groups (Database column: PARENT_GROUPID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("PARENT_GROUPID")
                .setMandatory(true)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(defaultGroup.getName(),defaultGroup);
        map.put(description.getName(),description);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(groups.getName(),groups);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/GroupsFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link Groups}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class GroupsFieldAttributes extends AbstractBeanAttributesDefinition{

    /** defaultGroup (Database column: DEFAULT_GROUP) */
    static public AttributeDefinition defaultGroup =
        new AttributeDefinition("defaultGroup")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("DEFAULT_GROUP")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** description (Database column: DESCRIPTION) */
    static public AttributeDefinition description =
        new AttributeDefinition("description")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("DESCRIPTION")
                .setMandatory(false)
                .setMaxSize(500)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(200)
                .setType(String.class);

    /** groups (Database column: PARENT_GROUPID) */
    static public AttributeDefinition groups =
        new AttributeDefinition("groups")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("GROUPS")
                .setDatabaseId("PARENT_GROUPID")
                .setMandatory(false)
                .setMaxSize(200)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Groups.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return "name";
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(defaultGroup.getName(),defaultGroup);
        map.put(description.getName(),description);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(groups.getName(),groups);

        return map;
    }
}
